==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>Markörer:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Inaktiva markörer:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Ursprung</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Origin:</source>
        <translation>Ursprung:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Relative zero:</source>
        <translation>Relativ nolla:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Rutnät</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Grid:</source>
        <translation>Rutnät:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Meta grid:</source>
        <translation type="unfinished">Meta-rutnät:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Markering</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Informationsverktyg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mått och etiketter:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Ritverktyg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Övriga figurer:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Zoomverktyg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation type="unfinished">Zoom lådlinje:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>Markörer:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Inaktiva markörer:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Ursprung</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Origin:</source>
        <translation>Ursprung:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Relative zero:</source>
        <translation>Relativ nolla:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Rutnät</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Grid:</source>
        <translation>Rutnät:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Meta grid:</source>
        <translation type="unfinished">Meta-rutnät:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Markering</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Informationsverktyg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mått och etiketter:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Ritverktyg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Övriga figurer:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Zoomverktyg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation type="unfinished">Zoom lådlinje:</translation>
    </message>
</context>
</TS>
